==> obj.mpp-2024.10-py3-none-any.whl: obj_mpp/task/validation/interface.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2018
SEE COPYRIGHT NOTICE BELOW
"""

import typing as h

from logger_36 import LOGGER
from obj_mpp.constant.config.parameter import VALID_REQUESTED_OUTPUTS
from obj_mpp.extension.function import CheckPassedParameters
from obj_mpp.interface.storage.api import (
    signal_details_h,
    signal_loading_fct_p,
    signal_output_fct_p,
)


def CheckLoadingFunction(
    SignalLoading_fct: signal_loading_fct_p | None,
    loading_prm: dict[str, h.Any],
    /,
) -> None:
    """"""
    if SignalLoading_fct is None:
        return

    CheckPassedParameters(
        SignalLoading_fct,
        loading_prm,
        signal_details_h,
    )


def CheckOutputFunction(
    SignalOutput_fct: signal_output_fct_p | None,
    output_prm: dict[str, h.Any],
    /,
) -> None:
    """"""
    if SignalOutput_fct is None:
        return

    CheckPassedParameters(SignalOutput_fct, output_prm, None)


def CheckRequestedOutputs(requested_outputs: tuple[str, ...], /) -> None:
    """"""
    if any(_elm not in VALID_REQUESTED_OUTPUTS for _elm in requested_outputs):
        actual = ", ".join(requested_outputs)
        LOGGER.StageIssue(
            f"At least one invalid requested output",
            actual=actual,
            expected=VALID_REQUESTED_OUTPUTS,
        )


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> obj.mpp-2025.7-py3-none-any.whl: obj_mpp/task/validation/interface.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2018
SEE COPYRIGHT NOTICE BELOW
"""

import typing as h

from logger_36 import L
from obj_mpp.constant.config.parameter import VALID_REQUESTED_OUTPUTS
from obj_mpp.extension.function import CheckPassedParameters
from obj_mpp.interface.storage.api import (
    signal_details_h,
    signal_loading_fct_p,
    signal_output_fct_p,
)


def CheckLoadingFunction(
    SignalLoading_fct: signal_loading_fct_p | None,
    loading_prm: dict[str, h.Any],
    /,
) -> None:
    """"""
    if SignalLoading_fct is None:
        return

    CheckPassedParameters(
        SignalLoading_fct,
        loading_prm,
        signal_details_h,
    )


def CheckOutputFunction(
    SignalOutput_fct: signal_output_fct_p | None,
    output_prm: dict[str, h.Any],
    /,
) -> None:
    """"""
    if SignalOutput_fct is None:
        return

    CheckPassedParameters(SignalOutput_fct, output_prm, None)


def CheckRequestedOutputs(requested_outputs: tuple[str, ...], /) -> None:
    """"""
    if any(_elm not in VALID_REQUESTED_OUTPUTS for _elm in requested_outputs):
        actual = ", ".join(requested_outputs)
        L.StageIssue(
            f"At least one invalid requested output",
            actual=actual,
            expected=VALID_REQUESTED_OUTPUTS,
        )


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
